==> mule-standalone-3.0.0.zip: org/mule/transformer/types/SimpleDataType.java <==
/*
 * $Id: SimpleDataType.java 19191 2010-08-25 21:05:23Z tcarlson $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.transformer.types;

import org.mule.api.MuleRuntimeException;
import org.mule.api.transformer.DataType;

import javax.activation.MimeType;
import javax.activation.MimeTypeParseException;

/**
 * A data type that simply wraps a Java type.  This type also allows a mime type to be associated
 * with the Java type.
 *
 * @since 3.0
 */
public class SimpleDataType<T> implements DataType<T>, Cloneable
{
    protected Class<?> type;
    protected String mimeType = ANY_MIME_TYPE;
    protected String encoding;

    public SimpleDataType(Class<?> type, String mimeType)
    {
        this.type = type;
        if (mimeType == null)
        {
            this.mimeType = ANY_MIME_TYPE;
        }
        else
        {
            try
            {
                MimeType mt = new MimeType(mimeType);
                this.mimeType = mt.getPrimaryType() + "/" + mt.getSubType();
                if (mt.getParameter("charset") != null)
                {
                    encoding = mt.getParameter("charset");
                }
            }
            catch (MimeTypeParseException e)
            {
                //TODO, this should really get thrown
                throw new MuleRuntimeException(e);
            }
        }
    }

    public SimpleDataType(Class type)
    {
        this.type = type;
    }

    public Class getType()
    {
        return type;
    }

    public String getMimeType()
    {
        return mimeType;
    }

    public void setMimeType(String mimeType)
    {
        this.mimeType = (mimeType == null ? ANY_MIME_TYPE : mimeType);
    }

    public String getEncoding()
    {
        return encoding;
    }

    public void setEncoding(String encoding)
    {
        this.encoding = encoding;
    }

    public boolean isCompatibleWith(DataType dataType)
    {
        if (dataType instanceof ImmutableDataType)
        {
            dataType = ((ImmutableDataType) dataType).getWrappedDataType();
        }
        if (this == dataType)
        {
            return true;
        }
        if (dataType == null)
        {
            return false;
        }

        SimpleDataType that = (SimpleDataType) dataType;

        //ANY_MIME_TYPE will match to a null or non-null value for MimeType        
        if ((this.getMimeType() == null && that.getMimeType() != null || that.getMimeType() == null && this.getMimeType() != null) && !ANY_MIME_TYPE.equals(this.mimeType) && !ANY_MIME_TYPE.equals(that.mimeType))
        {
            return false;
        }

        if (this.getMimeType() != null && !this.getMimeType().equals(that.getMimeType()) && !ANY_MIME_TYPE.equals(that.getMimeType()) && !ANY_MIME_TYPE.equals(this.getMimeType()))
        {
            return false;
        }

        if (!this.getType().isAssignableFrom(that.getType()))
        {
            return false;
        }

        return true;
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o)
        {
            return true;
        }
        if (o == null || getClass() != o.getClass())
        {
            return false;
        }

        SimpleDataType that = (SimpleDataType) o;

        if (!type.equals(that.type))
        {
            return false;
        }

        //ANY_MIME_TYPE will match to a null or non-null value for MimeType
        if ((this.mimeType == null && that.mimeType != null || that.mimeType == null && this.mimeType != null) && !ANY_MIME_TYPE.equals(that.mimeType))
        {
            return false;
        }

        if (this.mimeType != null && !mimeType.equals(that.mimeType) && !ANY_MIME_TYPE.equals(that.mimeType))
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = type.hashCode();
        result = 31 * result + (mimeType != null ? mimeType.hashCode() : 0);
        return result;
    }

    @Override
    public String toString()
    {
        return "SimpleDataType{" +
                "type=" + type.getName() +
                ", mimeType='" + mimeType + '\'' +
                '}';
    }

    public DataType cloneDataType()
    {
        try
        {
            return (DataType) clone();
        }
        catch (CloneNotSupportedException e)
        {
            // This cannot happen, because we implement Cloneable
            throw new IllegalStateException(e);
        }
    }
}

==> mule-standalone-3.1.0.zip: org/mule/transformer/types/SimpleDataType.java <==
/*
 * $Id: SimpleDataType.java 20582 2010-12-09 23:13:19Z dfeist $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.transformer.types;

import org.mule.api.MuleRuntimeException;
import org.mule.api.transformer.DataType;

import javax.activation.MimeType;
import javax.activation.MimeTypeParseException;

import org.apache.commons.beanutils.MethodUtils;

/**
 * A data type that simply wraps a Java type.  This type also allows a mime type to be associated
 * with the Java type.
 *
 * @since 3.0
 */
public class SimpleDataType<T> implements DataType<T>, Cloneable
{
    protected Class<?> type;
    protected String mimeType = ANY_MIME_TYPE;
    protected String encoding;

    public SimpleDataType(Class<?> type, String mimeType)
    {
        this.type = type;
        if (mimeType == null)
        {
            this.mimeType = ANY_MIME_TYPE;
        }
        else
        {
            try
            {
                MimeType mt = new MimeType(mimeType);
                this.mimeType = mt.getPrimaryType() + "/" + mt.getSubType();
                if (mt.getParameter("charset") != null)
                {
                    encoding = mt.getParameter("charset");
                }
            }
            catch (MimeTypeParseException e)
            {
                //TODO, this should really get thrown
                throw new MuleRuntimeException(e);
            }
        }
    }

    public SimpleDataType(Class type)
    {
        this.type = type;
    }

    public Class getType()
    {
        return type;
    }

    public String getMimeType()
    {
        return mimeType;
    }

    public void setMimeType(String mimeType)
    {
        this.mimeType = (mimeType == null ? ANY_MIME_TYPE : mimeType);
    }

    public String getEncoding()
    {
        return encoding;
    }

    public void setEncoding(String encoding)
    {
        this.encoding = encoding;
    }

    public boolean isCompatibleWith(DataType dataType)
    {
        if (dataType instanceof ImmutableDataType)
        {
            dataType = ((ImmutableDataType) dataType).getWrappedDataType();
        }
        if (this == dataType)
        {
            return true;
        }
        if (dataType == null)
        {
            return false;
        }

        SimpleDataType that = (SimpleDataType) dataType;

        //ANY_MIME_TYPE will match to a null or non-null value for MimeType        
        if ((this.getMimeType() == null && that.getMimeType() != null || that.getMimeType() == null && this.getMimeType() != null) && !ANY_MIME_TYPE.equals(this.mimeType) && !ANY_MIME_TYPE.equals(that.mimeType))
        {
            return false;
        }

        if (this.getMimeType() != null && !this.getMimeType().equals(that.getMimeType()) && !ANY_MIME_TYPE.equals(that.getMimeType()) && !ANY_MIME_TYPE.equals(this.getMimeType()))
        {
            return false;
        }

        if (!fromPrimitive(this.getType()).isAssignableFrom(fromPrimitive(that.getType())))
        {
            return false;
        }

        return true;
    }
    
    
    private Class<?> fromPrimitive(Class<?> type)
    {
        Class<?> primitiveWrapper = MethodUtils.getPrimitiveWrapper(type);
        if (primitiveWrapper != null)
        {
            return primitiveWrapper;
        }
        else
        {
            return type;
        }
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o)
        {
            return true;
        }
        if (o == null || getClass() != o.getClass())
        {
            return false;
        }

        SimpleDataType that = (SimpleDataType) o;

        if (!type.equals(that.type))
        {
            return false;
        }

        //ANY_MIME_TYPE will match to a null or non-null value for MimeType
        if ((this.mimeType == null && that.mimeType != null || that.mimeType == null && this.mimeType != null) && !ANY_MIME_TYPE.equals(that.mimeType))
        {
            return false;
        }

        if (this.mimeType != null && !mimeType.equals(that.mimeType) && !ANY_MIME_TYPE.equals(that.mimeType))
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = type.hashCode();
        result = 31 * result + (encoding != null ? encoding.hashCode() : 0);
        result = 31 * result + (mimeType != null ? mimeType.hashCode() : 0);
        return result;
    }

    
    @Override
    public String toString()
    {
        return "SimpleDataType{" +
                "type=" + type.getName() +
                ", mimeType='" + mimeType + '\'' +
                '}';
    }

    public DataType cloneDataType()
    {
        try
        {
            return (DataType) clone();
        }
        catch (CloneNotSupportedException e)
        {
            // This cannot happen, because we implement Cloneable
            throw new IllegalStateException(e);
        }
    }
}
